@@ -7,7 +7,12 @@ from werkzeug.wrappers import Response
 from requests_oauthlib.oauth1_session import TokenRequestDenied, TokenMissing
 from oauthlib.oauth1 import SIGNATURE_HMAC, SIGNATURE_TYPE_AUTH_HEADER
 from oauthlib.common import to_unicode
-from .base import BaseOAuthConsumerBlueprint, oauth_authorized, oauth_error
+from .base import (
+    BaseOAuthConsumerBlueprint,
+    oauth_authorized,
+    oauth_before_login,
+    oauth_error,
+)
 from .requests import OAuth1Session
 
 log = logging.getLogger(__name__)
@@ -17,30 +22,38 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
     """
     A subclass of :class:`flask.Blueprint` that sets up OAuth 1 authentication.
     """
-    def __init__(self, name, import_name,
-            client_key=None,
-            client_secret=None,
-            signature_method=SIGNATURE_HMAC,
-            signature_type=SIGNATURE_TYPE_AUTH_HEADER,
-            rsa_key=None,
-            client_class=None,
-            force_include_body=False,
 
-            static_folder=None, static_url_path=None, template_folder=None,
-            url_prefix=None, subdomain=None, url_defaults=None, root_path=None,
-
-            login_url=None,
-            authorized_url=None,
-            base_url=None,
-            request_token_url=None,
-            authorization_url=None,
-            access_token_url=None,
-            redirect_url=None,
-            redirect_to=None,
-            session_class=None,
-            backend=None,
-
-            **kwargs):
+    def __init__(
+        self,
+        name,
+        import_name,
+        client_key=None,
+        client_secret=None,
+        signature_method=SIGNATURE_HMAC,
+        signature_type=SIGNATURE_TYPE_AUTH_HEADER,
+        rsa_key=None,
+        client_class=None,
+        force_include_body=False,
+        static_folder=None,
+        static_url_path=None,
+        template_folder=None,
+        url_prefix=None,
+        subdomain=None,
+        url_defaults=None,
+        root_path=None,
+        login_url=None,
+        authorized_url=None,
+        base_url=None,
+        request_token_url=None,
+        authorization_url=None,
+        access_token_url=None,
+        redirect_url=None,
+        redirect_to=None,
+        session_class=None,
+        backend=None,
+        storage=None,
+        **kwargs
+    ):
         """
         Most of the constructor arguments are forwarded either to the
         :class:`flask.Blueprint` constructor or the
@@ -91,20 +104,25 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
                 between the consumer (your website) and the provider (e.g.
                 Twitter). Defaults to
                 :class:`~flask_dance.consumer.requests.OAuth1Session`.
-            backend: A storage backend class, or an instance of a storage
-                backend class, to use for this blueprint. Defaults to
-                :class:`~flask_dance.consumer.backend.session.SessionBackend`.
+            storage: A token storage class, or an instance of a token storage
+                class, to use for this blueprint. Defaults to
+                :class:`~flask_dance.consumer.storage.session.SessionStorage`.
         """
         BaseOAuthConsumerBlueprint.__init__(
-            self, name, import_name,
+            self,
+            name,
+            import_name,
             static_folder=static_folder,
             static_url_path=static_url_path,
             template_folder=template_folder,
-            url_prefix=url_prefix, subdomain=subdomain,
-            url_defaults=url_defaults, root_path=root_path,
+            url_prefix=url_prefix,
+            subdomain=subdomain,
+            url_defaults=url_defaults,
+            root_path=root_path,
             login_url=login_url,
             authorized_url=authorized_url,
             backend=backend,
+            storage=storage,
         )
 
         self.base_url = base_url
@@ -155,14 +173,13 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
 
     def login(self):
         callback_uri = url_for(
-            ".authorized", next=request.args.get('next'), _external=True,
+            ".authorized", next=request.args.get("next"), _external=True
         )
         self.session._client.client.callback_uri = to_unicode(callback_uri)
 
         try:
             self.session.fetch_request_token(
-                self.request_token_url,
-                should_load_token=False,
+                self.request_token_url, should_load_token=False
             )
         except TokenRequestDenied as err:
             message = err.args[0]
@@ -181,6 +198,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             return redirect(next_url)
 
         url = self.session.authorization_url(self.authorization_url)
+        oauth_before_login.send(self, url=url)
         return redirect(url)
 
     def authorized(self):
@@ -209,8 +227,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
 
         try:
             token = self.session.fetch_access_token(
-                self.access_token_url,
-                should_load_token=False,
+                self.access_token_url, should_load_token=False
             )
         except ValueError as err:
             # can't proceed with OAuth, have to just redirect to next_url
