@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
+
 try:
     from flask import _app_ctx_stack as stack
 except ImportError:
@@ -13,9 +14,18 @@ __maintainer__ = "Matt Bachmann <bachmann.matt@gmail.com>"
 
 
 def make_facebook_blueprint(
-        client_id=None, client_secret=None, scope=None, redirect_url=None,
-        redirect_to=None, login_url=None, authorized_url=None, rerequest_declined_permissions=False,
-        session_class=None, backend=None):
+    client_id=None,
+    client_secret=None,
+    scope=None,
+    redirect_url=None,
+    redirect_to=None,
+    login_url=None,
+    authorized_url=None,
+    rerequest_declined_permissions=False,
+    session_class=None,
+    backend=None,
+    storage=None,
+):
     """
     Make a blueprint for authenticating with Facebook using OAuth 2. This requires
     a client ID and client secret from Facebook. You should either pass them to
@@ -40,31 +50,34 @@ def make_facebook_blueprint(
         session_class (class, optional): The class to use for creating a
             Requests session. Defaults to
             :class:`~flask_dance.consumer.requests.OAuth2Session`.
-        backend: A storage backend class, or an instance of a storage
-                backend class, to use for this blueprint. Defaults to
-                :class:`~flask_dance.consumer.backend.session.SessionBackend`.
+        storage: A token storage class, or an instance of a token storage
+                class, to use for this blueprint. Defaults to
+                :class:`~flask_dance.consumer.storage.session.SessionStorage`.
 
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
     :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     authorization_url_params = {}
     if rerequest_declined_permissions:
-        authorization_url_params['auth_type'] = 'rerequest'
-    facebook_bp = OAuth2ConsumerBlueprint("facebook", __name__,
-                                          client_id=client_id,
-                                          client_secret=client_secret,
-                                          scope=scope,
-                                          base_url="https://graph.facebook.com/",
-                                          authorization_url="https://www.facebook.com/dialog/oauth",
-                                          authorization_url_params=authorization_url_params,
-                                          token_url="https://graph.facebook.com/oauth/access_token",
-                                          redirect_url=redirect_url,
-                                          redirect_to=redirect_to,
-                                          login_url=login_url,
-                                          authorized_url=authorized_url,
-                                          session_class=session_class,
-                                          backend=backend,
-                                          )
+        authorization_url_params["auth_type"] = "rerequest"
+    facebook_bp = OAuth2ConsumerBlueprint(
+        "facebook",
+        __name__,
+        client_id=client_id,
+        client_secret=client_secret,
+        scope=scope,
+        base_url="https://graph.facebook.com/",
+        authorization_url="https://www.facebook.com/dialog/oauth",
+        authorization_url_params=authorization_url_params,
+        token_url="https://graph.facebook.com/oauth/access_token",
+        redirect_url=redirect_url,
+        redirect_to=redirect_to,
+        login_url=login_url,
+        authorized_url=authorized_url,
+        session_class=session_class,
+        backend=backend,
+        storage=storage,
+    )
     facebook_bp.from_config["client_id"] = "FACEBOOK_OAUTH_CLIENT_ID"
     facebook_bp.from_config["client_secret"] = "FACEBOOK_OAUTH_CLIENT_SECRET"
 
